"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const chalk_1 = require("chalk");
const read_config_file_1 = require("./read-config-file");
const Options = require("./options");
const logger = require("./logger");
// tslint:disable-next-line:variable-name
const TsconfigPaths = require("tsconfig-paths");
const modulesInRootPlugin = require("enhanced-resolve/lib/ModulesInRootPlugin");
const createInnerCallback = require("enhanced-resolve/lib/createInnerCallback");
const getInnerRequest = require("enhanced-resolve/lib/getInnerRequest");
class TsConfigPathsPlugin {
    constructor(rawOptions = {}) {
        this.source = "described-resolve";
        this.target = "resolve";
        const options = Options.getOptions(rawOptions);
        const colors = new chalk_1.default.constructor({ enabled: options.colors });
        const log = logger.makeLogger(options, colors);
        const context = options.context || process.cwd();
        const { configFilePath, baseUrl, paths = {} } = read_config_file_1.readConfigFile(context, options.compiler, options.configFile);
        log.logInfo(`tsconfig-paths-webpack-plugin: Using config file at ${configFilePath}`);
        this.baseUrl = baseUrl;
        this.absoluteBaseUrl = path.resolve(path.dirname(configFilePath), this.baseUrl || ".");
        this.matchPath = TsconfigPaths.createMatchPath(this.absoluteBaseUrl, paths);
    }
    apply(resolver) {
        const { baseUrl } = this;
        if (!baseUrl) {
            // Nothing to do if there is no baseUrl
            return;
        }
        // This is for the baseUrl
        resolver.apply(new modulesInRootPlugin("module", this.absoluteBaseUrl, "resolve"));
        resolver.plugin(this.source, createPlugin(this.matchPath, resolver, this.absoluteBaseUrl, this.target));
    }
}
exports.TsConfigPathsPlugin = TsConfigPathsPlugin;
function createPlugin(matchPath, resolver, absoluteBaseUrl, target) {
    return (request, callback) => {
        const innerRequest = getInnerRequest(resolver, request);
        if (!innerRequest ||
            (innerRequest.startsWith(".") || innerRequest.startsWith(".."))) {
            return callback();
        }
        const foundMatch = matchPath(request.context.issuer, innerRequest, undefined, undefined, [".ts", ".tsx"]);
        if (!foundMatch) {
            return callback();
        }
        const newRequest = Object.assign({}, request, { request: foundMatch, path: absoluteBaseUrl });
        return resolver.doResolve(target, newRequest, 
        // `aliased with mapping '${innerRequest}': '${foundMapping.alias}' to '${
        //   relativeTargetPath
        // }'`,
        "aliased with mapping", createInnerCallback((err, result2) => {
            if (arguments.length > 0) {
                return callback(err, result2);
            }
            // don't allow other aliasing or raw request
            callback(null, null);
        }, callback));
    };
}
