"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const colors = require("colors/safe");
const COMPILER_ERROR = colors.red(`\n\nTypescript compiler cannot be found, please add it to your package.json file:
    npm install --save-dev typescript
`);
function findTsImplPackage(inputPath) {
    let pkgDir = path.dirname(inputPath);
    if (fs.readdirSync(pkgDir).find(value => value === "package.json")) {
        return path.join(pkgDir, "package.json");
    }
    else {
        return findTsImplPackage(pkgDir);
    }
}
function setupTs(compiler) {
    let compilerPath = compiler || "typescript";
    let tsImpl;
    let tsImplPath;
    try {
        tsImplPath = require.resolve(compilerPath);
        tsImpl = require(tsImplPath);
    }
    catch (e) {
        console.error(e);
        console.error(COMPILER_ERROR);
        process.exit(1);
    }
    const pkgPath = findTsImplPackage(tsImplPath);
    const compilerVersion = require(pkgPath).version;
    const compilerInfo = {
        compilerPath,
        compilerVersion,
        tsImpl
    };
    return compilerInfo;
}
function absolutize(fileName, context) {
    if (path.isAbsolute(fileName)) {
        return fileName;
    }
    else {
        return path.join(context, fileName);
    }
}
function readConfigFile(context, compiler, configFileName) {
    const tsImpl = setupTs(compiler).tsImpl;
    let configFilePath;
    if (configFileName && configFileName.match(/\.json$/)) {
        configFilePath = absolutize(configFileName, context);
    }
    else {
        configFilePath = tsImpl.findConfigFile(context, tsImpl.sys.fileExists);
    }
    // const existingOptions = tsImpl.convertCompilerOptionsFromJson(
    //   config,
    //   context,
    //   "atl.query"
    // );
    const jsonConfigFile = tsImpl.readConfigFile(configFilePath, tsImpl.sys.readFile);
    const compilerConfig = tsImpl.parseJsonConfigFileContent(jsonConfigFile.config, tsImpl.sys, path.dirname(configFilePath), 
    //existingOptions.options,
    {}, configFilePath);
    return {
        configFilePath,
        baseUrl: compilerConfig.options.baseUrl,
        paths: compilerConfig.options.paths
    };
}
exports.readConfigFile = readConfigFile;
